==> tuia-commercial-center-api-1.1.19-farm-20210112.025751-4-sources.jar: cn/com/duiba/tuia/commercial/center/api/dto/farm/FarmInitializeUserDto.java <==
package cn.com.duiba.tuia.commercial.center.api.dto.farm;

import lombok.Data;

import java.io.Serializable;
import java.util.Date;

/**
 * FarmInitializeUserDto
 * 用户初始化信息类
 * @author huangruodan
 * @date 2019-11-21
 */

@Data
public class FarmInitializeUserDto implements Serializable {

    private static final long serialVersionUID = -2450940620431712354L;

    /**
     * ID
     */
    private Long id;

    /**
     * 用户金币数
     */
    private Long cash;

    /**
     * 累计获得的金币
     */
    private Long obtainCash;

    /**
     * 用户有效红包数
     */
    private Integer redPacket;

    /**
     * 用户红包总数
     */
    private Integer redPacketNum;

    /**
     * 登录天数
     */
    private Integer signDays;

    /**
     * 登录天数
     */
    private Integer continueSignDays;

    /**
     * 上次登录时间
     */
    private Date lastSignTime;

    /**
     * 新手引导完成时的登录天数
     */
    private Integer newMissionSignDays;

    /**
     * 是否今日首次登陆
     */
    private Boolean signFlag;

    /**
     * 采摘次数
     */
    private Integer pickTimes;

    /**
     * 当前采摘次数
     */
    private Integer curPickTimes;

    /**
     * 离线收益
     */
    private Long offlineCash;

    /**
     * 阶梯
     */
    private Integer stage;

    /**
     * IP
     */
    private String ip;

    /**
     * 果实升级次数
     */
    private Integer fruitUpgradeTimes;

    /**
     * 是否点击过红包明细
     */
    private Boolean packetClick;

    /**
     * 灌溉次数
     */
    private Integer waterTimes;

    /**
     * 翻倍倍数
     */
    private Integer offlineMultiple;

    /**
     * 天降宝箱次数
     */
    private Integer boxTimes;


    /**
     * 上次heartbeat时间
     */
    private Date lastHeartbeatTime;
}

==> tuia-commercial-center-api-1.1.33-farm-20220118.073925-8-sources.jar: cn/com/duiba/tuia/commercial/center/api/dto/farm/FarmInitializeUserDto.java <==
package cn.com.duiba.tuia.commercial.center.api.dto.farm;

import lombok.Data;

import java.io.Serializable;
import java.util.Date;

/**
 * FarmInitializeUserDto
 * 用户初始化信息类
 *
 * @author huangruodan
 * @date 2019-11-21
 */

@Data
public class FarmInitializeUserDto implements Serializable {

    private static final long serialVersionUID = -2450940620431712354L;

    /**
     * ID
     */
    private Long id;

    /**
     * 用户金币数
     */
    private Long cash;

    /**
     * 累计获得的金币
     */
    private Long obtainCash;

    /**
     * 用户有效红包数
     */
    private Integer redPacket;

    /**
     * 用户红包总数
     */
    private Integer redPacketNum;

    /**
     * 登录天数
     */
    private Integer signDays;

    /**
     * 登录天数
     */
    private Integer continueSignDays;

    /**
     * 上次登录时间
     */
    private Date lastSignTime;

    /**
     * 新手引导完成时的登录天数
     */
    private Integer newMissionSignDays;

    /**
     * 是否今日首次登陆
     */
    private Boolean signFlag;

    /**
     * 墨迹天气定制：是否是VIP用户，0->非VIP用户，其他->VIP用户
     */
    private Integer vipUser;
    /**
     * 墨迹天气定制：收益加成配置，VIP玩家且天气为晴天/阴天，收获果实可以获得额外的加成
     */
    private Double vipIncrement;

    /**
     * 采摘次数
     */
    private Integer pickTimes;

    /**
     * 当前采摘次数
     */
    private Integer curPickTimes;

    /**
     * 离线收益
     */
    private Long offlineCash;

    /**
     * 阶梯
     */
    private Integer stage;

    /**
     * IP
     */
    private String ip;

    /**
     * 果实升级次数
     */
    private Integer fruitUpgradeTimes;

    /**
     * 是否点击过红包明细
     */
    private Boolean packetClick;

    /**
     * 灌溉次数
     */
    private Integer waterTimes;

    /**
     * 翻倍倍数
     */
    private Integer offlineMultiple;

    /**
     * 天降宝箱次数
     */
    private Integer boxTimes;


    /**
     * 上次heartbeat时间
     */
    private Date lastHeartbeatTime;

    /**
     * 高级货币数量
     */
    private Integer seniorCurrency;

    /**
     * 当前等级
     */
    private Integer currentLevel;

    /**
     * 当前经验值
     */
    private Long currentExp;

    /**
     * 升级所需经验值
     */
    private Long nextLevelExp;

    /**
     * 上次领取每日礼物的时间
     */
    private Date lastFetchGiftTime;

    /**
     * 点击通知的次数
     */
    private Integer noticeTimes;





}
